--
-- Migrate GH Tester database from schema version 1.9.17 to 1.9.18
--
DROP PROCEDURE IF EXISTS update_gh_schema;

DELIMITER //
CREATE PROCEDURE update_gh_schema()
BEGIN
  DECLARE current_version varchar(100);
  SET @required_version = '1.9.17';

  SELECT value INTO current_version FROM db_details WHERE 
         property='schema.version.number' AND 
         ctime = (
            SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number'
         );
  IF @required_version != current_version THEN
     SET @version_error = CONCAT( 'Incorrect schema version: ', current_version,
                                  ' expected: ', @required_version );
     SELECT @version_error;
  ELSE

--
-- The update script
--

drop table sonic_broker_ts;
drop table sonic_broker_mrv;

CREATE TABLE `sonic_broker_mrv`(
    `id`                  BIGINT          AUTO_INCREMENT,
    `sonic_agent_mrv_id`  BIGINT          NOT NULL,
    `broker`              VARCHAR(256)    NOT NULL,
    `time`                BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `sonic_broker_mrv_index1`(`sonic_agent_mrv_id`, `broker`), 
    FOREIGN KEY (`sonic_agent_mrv_id`)
    REFERENCES `sonic_agent_mrv`(`id`)
)ENGINE=INNODB
;


CREATE TABLE `sonic_broker_ts`(
    `idx`                  BIGINT    NOT NULL,
    `sonic_broker_mrv_id`  BIGINT    NOT NULL,
    `execution_id`         BIGINT,
    `time`                 BIGINT    NOT NULL,
    `appmsgreceived`       BIGINT,
    `appmsgdelivered`      BIGINT,
    `bytesreceived`        BIGINT,
    `bytesdelivered`       BIGINT,
    `connscount`           BIGINT,
    `connsreject`          BIGINT,
    `topicstoresize`       BIGINT,
    INDEX `sonic_broker_ts_index1`(`time`),
    INDEX `sonic_broker_ts_index2`(`execution_id`),
    INDEX `sys_c004611`(`sonic_broker_mrv_id`),
    INDEX `ref31104`(`execution_id`), 
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`sonic_broker_mrv_id`)
    REFERENCES `sonic_broker_mrv`(`id`)
)ENGINE=INNODB
;

INSERT INTO db_details VALUES
   ( now(), 'schema.version.number','1.9.18');

commit;

  END IF; -- Schema version check
END
//
DELIMITER ;

CALL update_gh_schema();

DROP PROCEDURE update_gh_schema;
