--
-- Migrate GH Tester database from schema version 1.9.23 to 1.9.24
--

DECLARE 
  required_version VARCHAR2(100);
  current_version VARCHAR2(100);
BEGIN
  SELECT '1.9.23' INTO required_version FROM dual;
  SELECT value INTO current_version FROM db_details 
    WHERE property='schema.version.number' 
    AND ctime = (
      SELECT MAX(ctime) FROM db_details WHERE property='schema.version.number' 
    );
    
   IF current_version != required_version THEN
     RAISE_APPLICATION_ERROR( -20001, 
                             'Incorrect schema version: ' || current_version  ||
                             ', expected: ' || required_version );
                             
   ELSE
-- 
-- Update Script here
--
EXECUTE IMMEDIATE
'ALTER TABLE 
    execution
ADD ( STATUS_ID NUMBER(10, 0) NULL )';

EXECUTE IMMEDIATE
'ALTER TABLE
    execution
ADD CONSTRAINT fk_execution_status_id
    FOREIGN KEY (status_id)
    REFERENCES status(id)';    



EXECUTE IMMEDIATE 'ALTER TABLE SCENARIO ADD UNIQUEID VARCHAR2(32)';
EXECUTE IMMEDIATE 'ALTER TABLE SCENARIO ADD APPMODELITEM_ID NUMBER(19, 0)';
EXECUTE IMMEDIATE 'ALTER TABLE SCENARIO ADD UNIQUE ("APPMODELITEM_ID", "UNIQUEID", "DISPLAY")';
EXECUTE IMMEDIATE 'ALTER TABLE SCENARIO ADD FOREIGN KEY ("APPMODELITEM_ID")
                    REFERENCES "APPMODELITEM"("ID") ON DELETE CASCADE'; 



COMMIT;

EXECUTE IMMEDIATE
'UPDATE 
    execution 
SET 
    status_id = (SELECT status_id FROM detail_execution d where d.execution_id = execution.id)';

EXECUTE IMMEDIATE
'ALTER TABLE
    detail_execution
DROP COLUMN
    status_id';

EXECUTE IMMEDIATE
'CREATE OR REPLACE FORCE VIEW  "SCENARIO_EXECUTIONS" ("EXECUTION_ID", "LABEL", "LOCKBY", "LOCKDATE", "NOTES_PK", "PROJECT_PK", "SUITE_PK", 
"SUITE_ID", "SUITE_NAME", "SCENARIO_NAME", "SCENARIO_ID", "START_TIME", "END_TIME", "STATUS") AS 
  SELECT sce.execution_id, l.label, u.username, u.time, n.execution_id, t.project_id, t.id, t.uniqueid, t.display, s.display, s.uniqueid, 
e.start_time, e.end_time, (SELECT display FROM status WHERE id = e.status_id)
  FROM scenario s, scenario_execution sce, execution e
  LEFT OUTER JOIN execution_label l ON e.id = l.execution_id
  LEFT OUTER JOIN (
    SELECT sue.execution_id, app.id, app.uniqueid, app.display, app.project_id
    FROM suite_execution sue, appmodelitem app
    WHERE sue.appmodelitem_id = app.id
  ) t ON e.id = t.execution_id
  LEFT OUTER JOIN (
    SELECT el.execution_id, p.username, el.time
    FROM execution_lock el, person p
    WHERE el.person_id = p.id
  ) u ON e.id = u.execution_id
  LEFT OUTER JOIN execution_note n ON e.id = n.execution_id
  WHERE e.id = sce.execution_id AND sce.scenario_id = s.id';

INSERT INTO db_details VALUES
   ( (SELECT sysdate FROM dual), 'schema.version.number','1.9.24');

COMMIT;


   END IF; -- version check
END;
/
